bayespy.inference.vmp.nodes.gaussian_markov_chain.GaussianMarkovChainMoments.get_converter
==========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian_markov_chain

.. automethod:: GaussianMarkovChainMoments.get_converter